library(testthat)
library(r2rtf)

test_check("r2rtf")
